@@ -6,7 +6,7 @@ from __future__ import absolute_import
 #from . import metrics
 #from . import parallel
 
-from .storage import download, ensure_available
+from .storage import download, ensure_available, download_onnx
 from .filesystem import get_model_dir
 from .filesystem import makedirs, try_import_dali
 from .constant import *
